/*********************************************************************
|  ----------------------------------------------------------------
|              Copyright (c) 2021 PikeTec GmbH
|  CONFIDENTIAL AND PROPRIETARY.ALL RIGHTS RESERVED -PROPRIETARY OF
|                       PikeTec GmbH
|********************************************************************/
#ifndef TPT_SFUN_INLINED_H
#define TPT_SFUN_INLINED_H

#include "TPT_Types.h"

typedef enum {
  tpt_not_initialized = 0, /* Status: TPT noch nicht initiliasiert */
  tpt_initialized     = 1, /* Status: Die TPT SFunction ist voll ausspezifiziert und ihr Interface steht fest in tpt_io */
  tpt_running         = 2, /* Status: Die Simulation laeuft */
  tpt_end             = 3, /* Status: Die Simulation ist fertig abgearbeitet */
  tpt_error           = 4  /* Status: Es ist ein Fehler aufgetreten */
} tpt_sfunction_status;

typedef enum {
  tpt_stop          = 0, /* Kommando: Auf den Ausgangssignalen werden die Standardwerte der SFunction geschrieben */
  tpt_initialize    = 1, /* Kommando: Byte-Daten liegen vor und koennen eingelesen werden. Solange die Daten noch */
                         /* nicht eingelesen sind werden die Standardwerte der SFunction auf die Ausgangskanaele geschrieben */
                         /* Wenn die Daten eingelesen sind werden die dort spezifizierten Standardwerte benutzt. */
  tpt_run           = 2, /* Kommando: Simulation laeuft */
  tpt_direct_start  = 3  /* Kommando: Direkter Start der Testausführung, die Umgebung ist vollständig initialisiert */
} tpt_sfunction_command;

typedef struct {
  tpt_uint16    tpt_ins_size;      /* Anzahl der Eingänge (entspricht genau der Länge der folgenden Listen) */
  void          **tpt_ins;         /* Liste von Pointern auf Speicheradressen, an denen Matlab die Werte ablegt */
  char          **tpt_ins_name;    /* Liste der Namen der Eingänge (geschrieben durch das generierte C-File) */
  int           *tpt_ins_vm_adr;   /* Liste der Adressen(Indices) der Kanäle in der TPT-VM */
  int           *tpt_ins_dim1;     /* Anzahl der Elemente in der ersten Dimension */
  int           *tpt_ins_dim2;     /* Anzahl der Elemente in der zweiten Dimension (0 für skalare und Arrays) */
  tpt_basetype  *tpt_ins_dataType; /* Liste der Datentypen der Eingänge */

  tpt_uint16    tpt_outs_size;      /* siehe oben */
  void          **tpt_outs;         /* siehe oben */
  char          **tpt_outs_name;    /* siehe oben */
  int           *tpt_outs_vm_adr;   /* siehe oben */
  int           *tpt_outs_dim1;     /* Anzahl der Elemente in der ersten Dimension */
  int           *tpt_outs_dim2;     /* Anzahl der Elemente in der zweiten Dimension (0 für skalare und Arrays) */
  tpt_basetype  *tpt_outs_dataType; /* siehe oben */
} tpt_in_out;

#if (!defined(INT64_T))
  typedef tpt_int64 int64_T;
#endif

#if defined(__cplusplus)
extern "C"
{
#endif

/* Benachrichtigt Matlab mit einer Fehlermeldung. Bricht einen laufenden Testlauf in Matlab ab. */
TPT_DECLARE(void) tpt_reportError(const char *e);       /* Fehlermeldung */

TPT_DECLARE(int) tpt_sfun_init(const tpt_double stepsize, const tpt_byte **err_chan,
          const char *prog_file, const char *bin_file,
          const tpt_in_out *ioDescription, const tpt_bool initOnlyMode);
		  
TPT_DECLARE(int) tpt_sfun(const tpt_double stepsize, const tpt_byte **err_chan,
          const char *prog_file, const char *bin_file,
          const tpt_in_out *ioDescription);

TPT_DECLARE(void) tpt_sfun_hil(const tpt_byte *prgdes, const tpt_uint32 p_width0,
          const tpt_double stepsize, const tpt_uint8 *steuer, tpt_uint8 *status,
          const tpt_byte **err_chan, const char *bin_file, const tpt_uint32 bf_length,
          const tpt_in_out *ioDesc);

TPT_DECLARE(void) tpt_sfun_terminate();

#if defined(__cplusplus)
}
#endif

#endif /* TPT_SFUN_INLINED_H */
