/*********************************************************************
|  ----------------------------------------------------------------
|              Copyright (c) 2021 PikeTec GmbH
|  CONFIDENTIAL AND PROPRIETARY. ALL RIGHTS RESERVED - PROPRIETARY OF
|                       PikeTec GmbH
|********************************************************************/

#ifndef TPT_SFUN_UTILS_H
#define TPT_SFUN_UTILS_H

/* MAKRO based utilities */ 
#define ASSIGN_CUSTOM_PORT_TYPE(TARGET, TYPE_ML_NAME) \
{ \
DTypeId customTypeId; \
ssRegisterTypeFromNamedObject(S, TYPE_ML_NAME, &customTypeId); \
if (customTypeId == INVALID_DTYPE_ID) \
  return; \
TARGET = customTypeId; \
} 

/* type definitions for Simulink interface data */ 
typedef struct {
  DTypeId portType;
  fxpModeRounding fixptRoundingMode;
  fxpModeOverflow fixptOverflowMode;
  int_T nLeafElems;
  DTypeId *leafElemMlTypes;
} tpt_sl_port_data;

typedef struct {
  char* name;
  tpt_sl_port_data argData;
} tpt_sl_function_arg_data;

typedef struct {
  char* name;
  int_T nInputArgs;
  tpt_sl_function_arg_data * inputArgsData;
  int_T nOutpututArgs;
  tpt_sl_function_arg_data * outputArgsData;
} tpt_sl_function_data;

/**
* Initialize (if not yet initialized) and return int64 data type based on unscaled fixpt type
*/
static DTypeId tptInitInt64Type(SimStruct* S);

static tpt_bool tptIsInt64TypeInitalized();

/**
* Get int64 type id, must only be used if initalized (check via tptIsInt64TypeInitalized)
*/
static DTypeId tptGetInt64Type();

/* Report error from TPT to the Simulink Engine */
static void tptReportError(void *simStructPtr, char *msg);

/**
* Initializes all internal port data for one given port based on the given data type and dimensions
*/
static tpt_bool tptInitTptPortData(SimStruct* S, char* signalName, tpt_sl_port_data *mlPortData, int dim1, int dim2, tpt_bool isNonVirtualBus, tpt_port_data * outTptPortData);

/**
* Initialize an input port of the S-function (via the MATLAB S-function Api)
*/
static void tptInitInputPort(SimStruct* S, int portNum,  tpt_sl_port_data *mlPortData, tpt_port_data * tptPortData, tpt_bool useDirectFeedThrough);

/**
* Initialize an output port of the S-function (via the MATLAB S-function Api)
*/
static void tptInitOutputPort(SimStruct* S, int portNum, tpt_sl_port_data *mlPortData, tpt_port_data * tptPortData);

/**
* Initializes all internal port data for function call signals
*/
static void tptInitFcnCallsPortData(SimStruct* S, const char* fcnCallSignalNames[], const tpt_tsize fcnCallSignalDims[], int nFcnCalls, tpt_sl_port_data *mlPortData, tpt_port_data * outTptPortData, 
    tpt_bool **fcnCallStates,  tpt_bool **fcnCallStatesOld, tpt_tsize *outTotalFcnCallsDim); 


/**
* Free all memory allocated for the interface data
*/
static void tptCleanupPortInterfaceData(tpt_in_out *ifData, tpt_sl_port_data *slInportData, tpt_sl_port_data *slOutportData, 
  tpt_bool **fcnCallStates, tpt_bool **fcnCallStatesOld, tpt_tsize *nFcnCallStates);
  
/**
 * Assign addresses of MATLAB input port signals to tptPortData structure
*/
static void tptAssignInputPortSignalAddresses(SimStruct* S, tpt_in_out* tptIO);

/**
 * Assign addresses of MATLAB output port signals to tptPortData structure
*/
static void tptAssignOutputPortSignalAddresses(SimStruct* S, tpt_in_out* tptIO, tpt_bool firstOutIsFcnCall);

#ifdef TPT_SFUN_FRAME
/**
 * Copy value from the TPT VM to a Simulink output port and apply scaling, called from the inner part of the S-function
*/
static void tptCopyOutportFixdtDataTptToSl(void *simStructPtr, tpt_uint32 portIdx, tpt_uint32 elemIdx, 
  void *tptVMAddress, tpt_basetype vmType, tpt_uint8 vmByteSize, 
  void *mlAddress, tpt_uint32 mlTypeSize);
  
/**
 * Copy value from a Simulink input port to the TPT VM and apply scaling, called from the inner part of the S-function
*/
static void tptCopyInportFixdtDataSlToTpt(void *simStructPtr, tpt_uint32 portIdx, tpt_uint32 elemIdx, 
  void *tptVMAddress, tpt_basetype vmType, tpt_uint8 vmByteSize, 
  void *mlAddress, tpt_uint32 mlTypeSize);
#endif /* TPT_SFUN_FRAME */

#ifdef TPT_USE_SL_FCN_STUB
/**
 * Copy value from the TPT VM to a Simulink function argument and apply scaling, called from the inner part of the S-function
*/
static void tptCopyFcnOutArgFixdtDataTptToSl(void *simStructPtr, tpt_int32 serverFcnIdx, tpt_uint32 portIdx, tpt_uint32 elemIdx, 
  void *tptVMAddress, tpt_basetype vmType, tpt_uint8 vmByteSize, 
  void *mlAddress, tpt_uint32 mlTypeSize);
  
/**
 * Copy value from a Simulink function argument to the TPT VM and apply scaling, called from the inner part of the S-function
*/
static void tptCopyFcnInArgFixdtDataSlToTpt(void *simStructPtr, tpt_int32 serverFcnIdx, tpt_uint32 portIdx, tpt_uint32 elemIdx, 
  void *tptVMAddress, tpt_basetype vmType, tpt_uint8 vmByteSize, 
  void *mlAddress, tpt_uint32 mlTypeSize);

/**
* Initializes all internal data for arguments signals of a simulink function
*/
static void tptInitFunctionArg(SimStruct* S, tpt_sl_function_data *slFcnData, tpt_sl_function_arg_data *slFcnArgData, int dim1, int dim2, tpt_port_data *tptFcnArgData);


static void tptAssignSimulinkFunctionArgumentAddresses(SimStruct* S, ssFcnCallExecArgs *args, tpt_fcn_data *tptServerFcnData);

static void tptCleanupFcnInterfaceData(const tpt_server_functions *fcn_data, tpt_sl_function_data *slServerFunctionData);

#endif /* TPT_USE_SL_FCN_STUB */

#endif
