function tptSim( model, timeout )
% TPTSIM(model,timeout) Simulate the model with the given timeout and store
% outputs (logsout, tout, etc.) in the base workspace.
if tptIsMinMatlabVersion(8, 6)
    % MATLAB version >= R2015b
    if exist('tl_get_blocks.m', 'file') == 2 && ...
            ~isempty(tl_get_blocks(model, 'TargetLink Main Dialog'))
        % TargetLink model:
        % TL Error E02440(1): model parameter may not be set in sim command
        cfgSet = getActiveConfigSet(model);
        if isa(cfgSet, 'Simulink.ConfigSetRef')
            % set StopTime in referenced configuration set
            realCfgSet = cfgSet.getRefConfigSet();
            set_param(realCfgSet, 'StopTime', num2str(timeout));
        else
            % set StopTime in non-referenced configuration set
            set_param(model, 'StopTime', num2str(timeout));
        end
        % TL Error E02440(5): when called from within a function, 'tl_sim'
        % should be used instead of 'sim' (problem with MATLAB >= R2015b).
        tl_sim(model);
        % note: additional outputs (like logsout, tout etc.) are stored in
        % the base workspace by 'tl_sim'
    else
        % Simulink model: new sim command (compatible with fast restart)
        sout = sim(model, 'StopTime', num2str(timeout));
        % extract any additional outputs to the base workspace
        % (logsout, tout, yout, ToWorkspace outputs, ...)
        try
            vars = sout.who;
            for i = 1 : length(vars)
                var = vars{i};
                try
                    val = sout.get(var);
                    assignin('base', var, val);
                catch ERR2
                    disp(['TPT > Extracting the additional model output ''', var, ...
                        ''' to the workspace failed: ', ERR2.message]);
                end
            end
        catch ERR
            disp(['TPT > Extracting additional model outputs (such as logging ', ...
                'data or ToWorkspace outputs) to the workspace failed: ', ERR.message]);
        end
    end
else
    % MATLAB version < R2015b: use the old sim command
    sim(model, [0 timeout], simset('SrcWorkspace', 'base', 'DstWorkspace', 'base'));
end

end
