package com.etas.ascet.api;

import org.eclipse.jdt.annotation.NonNullByDefault;

import com.google.auto.value.AutoValue;
import com.ryanharter.auto.value.gson.GenerateTypeAdapter;

/**
 * API version info
 */
// Checkstyle:off
@NonNullByDefault
@GenerateTypeAdapter
@AutoValue
public abstract class ApiVersionDto {

    /**
     * The major version number of an API
     */
    public abstract int versionMajor();

    /**
     * The minor version number of an API
     */
    public abstract int versionMinor();

    /**
     * <code>true</code> when this version is a released version and is not going to be altered in future versions
     * of ASCET-DEVELOPER.
     * But it might be deprecated and be removed at some time.
     */
    public abstract boolean preReleased();

    /**
     * <code>true</code> if client really should migrate to new versions,
     * because this version might be removed in the next ASCET-DEVELOPER release.
     */
    public abstract boolean isDeprecated();

    public static Builder builder() {
        return new AutoValue_ApiVersionDto.Builder();
    }

    @AutoValue.Builder
    public interface Builder {
        /**
         * @see ApiVersionDto#versionMajor()
         */
        Builder versionMajor(int value);

        /**
         * @see ApiVersionDto#versionMinor()
         */
        Builder versionMinor(int value);

        /**
         * @see ApiVersionDto#preReleased()
         */
        Builder preReleased(boolean value);

        /**
         * @see ApiVersionDto#isDeprecated()
         */
        Builder isDeprecated(boolean value);

        ApiVersionDto build();
    }
}
