package com.etas.ascet.api;

import org.eclipse.jdt.annotation.NonNullByDefault;

import com.etas.ascet.api.v1.ClientApiV1;
import com.etas.ascet.api.v1.LocalApiV1;

/**
 * Factory for API objects instances
 */
@NonNullByDefault
public interface AscetApiFactory {

    /**
     * Create instance of generic API.
     * The caller must call {@link LocalApiGeneric#dispose()} when finished with the api,
     * to ensure all cached references are freed.
     *
     * @param client
     *            the client side implementation which can be called by the API
     * @return the created object
     */
    LocalApiGeneric createAscetApiGeneric(ClientApiGeneric client);

    /**
     * Create instance of v1 API
     * The caller must call {@link LocalApiV1#dispose()} when finished with the api,
     * to ensure all cached references are freed.
     *
     * @param client
     *            the client side implementation which can be called by the API
     * @return the created object
     */
    LocalApiV1 createAscetApiV1(ClientApiV1 client);

}
