package com.etas.ascet.api.v1.datatype;

import java.math.BigDecimal;
import java.util.List;

import org.eclipse.jdt.annotation.NonNullByDefault;

import com.google.auto.value.AutoValue;
import com.ryanharter.auto.value.gson.GenerateTypeAdapter;

// Checkstyle:off
@NonNullByDefault
@GenerateTypeAdapter
@AutoValue
public abstract class ApplicationTaskDtoV1 {

    public abstract ApplicationTaskTypeV1 type();

    /**
     * The name of the task.
     * Only valid for {@link ApplicationTaskTypeV1#SCHEDULED} and {@link ApplicationTaskTypeV1#EVENT}.
     * For {@link ApplicationTaskTypeV1#STARTUP} and {@link ApplicationTaskTypeV1#SHUTDOWN} these are the enum names.
     */
    public abstract String name();

    /**
     * The initial delay of first execution in seconds. Only valid for {@link ApplicationTaskTypeV1#SCHEDULED}.
     */
    public abstract BigDecimal delaySec();

    /**
     * The period duration of execution in seconds. Only valid for {@link ApplicationTaskTypeV1#SCHEDULED}.
     */
    public abstract BigDecimal periodSec();

    /**
     * The OS specific priority. The lower the value, the more precedence the task has.
     * With priority 0 the task cannot be interrupted by other tasks, an idling task has the highest priority number.
     */
    public abstract int priority();

    /**
     * Type of scheduling. Preemptive/cooperative/...
     */
    public abstract ApplicationTaskSchedulingV1 scheduling();

    /**
     * List of identifier to process/thread method declarations to be executed in this task.
     */
    public abstract List<IdentifierDtoV1> processes();

    public static Builder builder() {
        return new AutoValue_ApplicationTaskDtoV1.Builder()
                .delaySec(BigDecimal.ZERO)
                .periodSec(BigDecimal.ZERO)
                .priority(0)
                .scheduling(ApplicationTaskSchedulingV1.NONE);
    }

    @AutoValue.Builder
    public interface Builder {

        /**
         * @see ApplicationTaskDtoV1#type()
         */
        Builder type(ApplicationTaskTypeV1 value);

        /**
         * @see ApplicationTaskDtoV1#name()
         */
        Builder name(String value);

        /**
         * @see ApplicationTaskDtoV1#delaySec()
         */
        Builder delaySec(BigDecimal value);

        /**
         * @see ApplicationTaskDtoV1#periodSec()
         */
        Builder periodSec(BigDecimal value);

        /**
         * @see ApplicationTaskDtoV1#priority()
         */
        Builder priority(int value);

        /**
         * @see ApplicationTaskDtoV1#scheduling()
         */
        Builder scheduling(ApplicationTaskSchedulingV1 value);

        /**
         * @see ApplicationTaskDtoV1#processes()
         */
        Builder processes(List<IdentifierDtoV1> value);

        ApplicationTaskDtoV1 build();
    }
}
