package com.etas.ascet.api.v1.datatype;

import org.eclipse.jdt.annotation.NonNullByDefault;

import com.google.auto.value.AutoValue;
import com.ryanharter.auto.value.gson.GenerateTypeAdapter;

// Checkstyle:off
@NonNullByDefault
@GenerateTypeAdapter
@AutoValue
public abstract class LaunchCreateWithDefaultsRequestDtoV1 {

    /**
     * The name of the launch configuration, as it is visible in the tree of the "Run ..." dialog.
     * This name must be unique. If it already exists, a unique name is created. See the result value.
     */
    public abstract String launchName();

    /**
     * One of the LAUNCHTYPE_* constants
     */
    public abstract String launchType();

    /**
     * The entry point resource for the launch type. E.g. for ECU code generation the application (.app) file.
     */
    public abstract String entryPointResource();

    /**
     * If empty, the configuration shall not be stored into a file.
     * If non-empty, this is a project name.
     * The config will be store based on its name with .launch extension in the project.
     */
    public abstract String projectName();

    public static Builder builder() {
        return new AutoValue_LaunchCreateWithDefaultsRequestDtoV1.Builder();
    }

    @AutoValue.Builder
    public interface Builder {

        /**
         * @see LaunchCreateWithDefaultsRequestDtoV1#launchName()
         */
        Builder launchName(String value);

        /**
         * @see LaunchCreateWithDefaultsRequestDtoV1#launchType()
         */
        Builder launchType(String value);

        /**
         * @see LaunchCreateWithDefaultsRequestDtoV1#entryPointResource()
         */
        Builder entryPointResource(String value);

        /**
         * @see LaunchCreateWithDefaultsRequestDtoV1#projectName()
         */
        Builder projectName(String value);

        LaunchCreateWithDefaultsRequestDtoV1 build();
    }
}
