package com.etas.ascet.api.v1.datatype;

import java.util.List;

import org.eclipse.jdt.annotation.NonNullByDefault;

import com.google.auto.value.AutoValue;
import com.ryanharter.auto.value.gson.GenerateTypeAdapter;

/**
 * Class type in the target view as further specification of {@link TargetTypeDtoV1}
 * In target view, the class exists with representation.
 * That means multiple {@link TargetClassTypeDtoV1} can exist for the same model class,
 * if there are multiple representation for this class in use in the actual application.
 */
// Checkstyle:off
@NonNullByDefault
@GenerateTypeAdapter
@AutoValue
public abstract class TargetClassTypeDtoV1 {

    public abstract IdentifierDtoV1 identifier();

    /**
     * The model class that is used for this target class.
     * Multiple {@link TargetClassTypeDtoV1} can link to the same model class,
     * if they only differ in the used representation.<br/>
     * <b>Note</b>: model class DTOs are not yet available, only the identifiers can be used to detect equality.
     */
    public abstract IdentifierDtoV1 modelClass();

    /**
     * Type of class, e.g. stateless or singleton
     */
    public abstract ClassKindV1 classKind();

    /**
     * Annotation attached to the class type
     */
    public abstract List<AnnotationDtoV1> annotations();

    /**
     * The fields declared within this class type.<br/>
     * Currently, this feature is not supported. An empty List is always returned.
     */
    public abstract List<DeclarationDtoV1> fields();

    /**
     * Method contained in the class. Those include methods, initializers
     */
    public abstract List<TargetMethodDtoV1> methods();

    public abstract CompositeRepresentationDtoV1 representation();

    public static Builder builder() {
        return new AutoValue_TargetClassTypeDtoV1.Builder();
    }

    @AutoValue.Builder
    public interface Builder {

        /**
         * @see TargetClassTypeDtoV1#identifier()
         */
        Builder identifier(IdentifierDtoV1 value);

        /**
         * @see TargetClassTypeDtoV1#modelClass()
         */
        Builder modelClass(IdentifierDtoV1 value);

        /**
         * @see TargetClassTypeDtoV1#classKind()
         */
        Builder classKind(ClassKindV1 value);

        /**
         * @see TargetClassTypeDtoV1#annotations()
         */
        Builder annotations(List<AnnotationDtoV1> value);

        /**
         * @see TargetClassTypeDtoV1#fields()
         */
        Builder fields(List<DeclarationDtoV1> value);

        /**
         * @see TargetClassTypeDtoV1#methods()
         */
        Builder methods(List<TargetMethodDtoV1> value);

        /**
         * @see TargetClassTypeDtoV1#representation()
         */
        Builder representation(CompositeRepresentationDtoV1 value);

        TargetClassTypeDtoV1 build();
    }
}
